@@ -1,7 +1,7 @@
 package Perinci::Sub::Gen::AccessTable;
 
-our $DATE = '2015-02-18'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $DATE = '2015-04-09'; # DATE
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,7 +66,7 @@ sub _add_arg {
     my $schema = ref($args{type}) eq 'ARRAY' ? $args{type} :
         [$args{type} => {}];
     $schema->[1] //= {};
-    $schema->[1]{default} = $args{default};
+    $schema->[1]{default} = $args{default} if defined($args{default});
     my $arg_spec = {
         schema => $schema,
         tags => [$tag],
@@ -1413,7 +1413,7 @@ Perinci::Sub::Gen::AccessTable - Generate function (and its metadata) to read ta
 
 =head1 VERSION
 
-This document describes version 0.44 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-02-18.
+This document describes version 0.45 of Perinci::Sub::Gen::AccessTable (from Perl distribution Perinci-Sub-Gen-AccessTable), released on 2015-04-09.
 
 =head1 SYNOPSIS
 
